"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultTypeValue = defaultTypeValue;
exports.defaultFieldValue = defaultFieldValue;
exports.getAlternativeWidget = getAlternativeWidget;
exports.getDefaultFormState = getDefaultFormState;
exports.asNumber = asNumber;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _componentsWidgetsRadioWidget = require("./components/widgets/RadioWidget");

var _componentsWidgetsRadioWidget2 = _interopRequireDefault(_componentsWidgetsRadioWidget);

var _componentsWidgetsUpDownWidget = require("./components/widgets/UpDownWidget");

var _componentsWidgetsUpDownWidget2 = _interopRequireDefault(_componentsWidgetsUpDownWidget);

var _componentsWidgetsRangeWidget = require("./components/widgets/RangeWidget");

var _componentsWidgetsRangeWidget2 = _interopRequireDefault(_componentsWidgetsRangeWidget);

var _componentsWidgetsSelectWidget = require("./components/widgets/SelectWidget");

var _componentsWidgetsSelectWidget2 = _interopRequireDefault(_componentsWidgetsSelectWidget);

var _componentsWidgetsTextareaWidget = require("./components/widgets/TextareaWidget");

var _componentsWidgetsTextareaWidget2 = _interopRequireDefault(_componentsWidgetsTextareaWidget);

function defaultTypeValue(type) {
  switch (type) {
    case "array":
      return [];
    case "boolean":
      return false;
    case "date-time":
      return "";
    case "number":
      return 0;
    case "object":
      return {};
    case "string":
      return "";
    default:
      return undefined;
  }
}

function defaultFieldValue(formData, schema) {
  return formData === null ? defaultTypeValue(schema.type) : formData;
}

function getAlternativeWidget(type, name) {
  switch (type) {
    case "boolean":
      switch (name) {
        case "radio":
          return _componentsWidgetsRadioWidget2["default"];
        case "select":
          return _componentsWidgetsSelectWidget2["default"];
        default:
          throw new Error("No alternative widget \"" + name + "\" for type " + type);
      }
      break;
    case "string":
      switch (name) {
        case "radio":
          return _componentsWidgetsRadioWidget2["default"];
        case "select":
          return _componentsWidgetsSelectWidget2["default"];
        case "textarea":
          return _componentsWidgetsTextareaWidget2["default"];
        default:
          throw new Error("No alternative widget \"" + name + "\" for type " + type);
      }
      break;
    case "number":
    case "integer":
      switch (name) {
        case "updown":
          return _componentsWidgetsUpDownWidget2["default"];
        case "range":
          return _componentsWidgetsRangeWidget2["default"];
        default:
          throw new Error("No alternative widget \"" + name + "\" for type " + type);
      }
      break;
    default:
      throw new Error("No alternative widget for type " + type);
  }
}

function getDefaultFormState(schema) {
  if (typeof schema !== "object") {
    throw new Error("Invalid schema: " + schema);
  }
  if ("default" in schema) {
    return schema["default"];
  }
  if (schema.type === "object") {
    return Object.keys(schema.properties).reduce(function (acc, key) {
      acc[key] = getDefaultFormState(schema.properties[key]);
      return acc;
    }, {});
  }
  return defaultTypeValue(schema.type);
}

function asNumber(value) {
  var n = Number(value);
  var valid = typeof n === "number" && !Number.isNaN(n);
  return valid ? n : value;
}